# Models API Reference

This page documents all the data models used in the library.

## Datum Model
::: kupo.models.Datum

## Health Model
::: kupo.models.Health

## Match Model
::: kupo.models.Match

## Metadata Model
::: kupo.models.Metadata

## Pattern Model
::: kupo.models.Pattern

## Point Model
::: kupo.models.Point

## Script Model
::: kupo.models.Script 